Package: fImport
Title: Rmetrics - Importing Economic and Financial Data
Version: 4052.89
Authors@R: c(person("Diethelm", "Wuertz", role="aut", comment = "original code")
	   , person("Tobias", "Setz", role = c("aut"), email = "tobias.setz@live.com")
	   , person("Yohan", "Chalabi", role = "aut")
	   , person(given = c("Georgi", "N."), family = "Boshnakov", 
                    role = c("cre", "aut"), email = "georgi.boshnakov@manchester.ac.uk",
		    comment = c(ORCID = "0000-0003-2839-346X")) )
Description: Provides a collection of utility functions 
    to download and manage data sets from the Internet or from other 
    sources.
Depends: R (>= 2.15.1), timeDate, timeSeries
Imports: methods, utils
Suggests: RUnit, rvest, xml2
LazyData: yes
License: GPL (>= 2)
URL: https://geobosh.github.io/fImportDoc/ (doc),
        https://CRAN.R-project.org/package=fImport,
        https://www.rmetrics.org
BugReports: https://r-forge.r-project.org/tracker/?atid=633&group_id=156&func=browse
NeedsCompilation: no
Packaged: 2025-12-18 12:38:38 UTC; georgi
Author: Diethelm Wuertz [aut] (original code),
  Tobias Setz [aut],
  Yohan Chalabi [aut],
  Georgi N. Boshnakov [cre, aut] (ORCID:
    <https://orcid.org/0000-0003-2839-346X>)
Maintainer: Georgi N. Boshnakov <georgi.boshnakov@manchester.ac.uk>
Repository: CRAN
Date/Publication: 2025-12-18 16:20:02 UTC
Built: R 4.6.0; ; 2026-04-26 18:05:36 UTC; unix
